@@ -1,4 +1,5 @@
 import tkinter as tk
+import tkinter.simpledialog as sd
 
 import cv2
 import matplotlib.pyplot as plt
@@ -17,12 +18,14 @@ from .sim_import import Simulation
 
 
 class DoseFigureHandler:
-    def __init__(self, parent, norm, zoom):
+    def __init__(self, parent):
 
         self.parent = parent
 
-        self.norm = norm
-        self.zoom = zoom
+        self.norm = self.parent.norm.get()
+        self.zoom = self.parent.zoom.get()
+        self.half = self.parent.half.get()
+        self.addmenu = False
 
         # Initialize the current settings
         self.lang = self.parent.lang
@@ -30,15 +33,16 @@ class DoseFigureHandler:
         self.style = plt.style.use("default")
         self.current_mode = self.parent.dark.get()
         self.colors = {
-            False: ["#ff2e1b", "#ffa43c", "#1bff67", "#ff5cf1", "#493cff"],
+            False: ["#ffa43c", "#ff2e1b", "#1bff67", "#ff5cf1", "#493cff"],
             True: ["#ff7fff", "#ffff00", "#00ffff", "#ff4040", "#40ff40"],
         }
         self.marker = "o--"
         self.markersize = self.parent.profile.get_attribute("markersize")
         self.linewidth = self.parent.profile.get_attribute("linewidth")
         # Initialize the figure and axes
-        self.fig = Figure(figsize=(10, 5), constrained_layout=True, dpi=1200)
+        self.fig = Figure(figsize=(10, 5), constrained_layout=True, dpi=600)
         self.canvas = FigureCanvasAgg(self.fig)
+        self.fig.set_canvas(self.canvas)
         self.ax = self.fig.add_subplot(111)
 
         # Initialize necessary variables
@@ -118,43 +122,66 @@ class DoseFigureHandler:
         Adds data to the plot queue
         """
 
+        test = [plotdata.direction for plotdata in self.plots]
         for tuple in datanames:
             filename = tuple[0]
             type = tuple[1]
             if filename not in [plotdata.filepath for plotdata in self.plots]:
                 if type == "simulation":
-                    self.plots += [Simulation(filename)]
+                    sim = Simulation(filename)
+                    if test == []:
+                        self.plots += [sim]
+                    elif sim.direction in test:
+                        self.plots += [sim]
+                    else:
+                        sd.messagebox.showinfo(
+                            "", f"{sim.filename}" + self.text.incordata[self.lang][1]
+                        )
                 elif type == "ptw":
                     importer = PTWMultimporter(filename, self.parent.parent)
                     importer.window.mainloop()
-                    self.plots += [plot for plot in importer.plots]
                     importer.window.destroy()
+                    measurements = [plot for plot in importer.plots]
+                    fails = []
+                    for plot in measurements:
+                        if test == []:
+                            self.plots += [plot]
+                            test += [plotdata.direction for plotdata in self.plots]
+                        elif plot.direction in test:
+                            self.plots += [plot]
+                            test += [plotdata.direction for plotdata in self.plots]
+                        else:
+                            fails += [plot]
+
+                    if fails != []:
+                        names = ""
+                        for f in fails:
+                            names += str(f.filename) + ", "
+                        names = names[:-2]
+                        var = 1
+                        if len(fails) >= 2:
+                            var = 2
+                        sd.messagebox.showinfo(
+                            "", f"{names}" + self.text.incordata[self.lang][var],
+                        )
                     del importer
 
                 else:
                     self.plots += [Measurement(filename, type)]
 
+        if self.plots[0].direction == "Z":
+            self.half = False
+
         for plotdata in self.plots:
-            if self.norm == True:
-                self.data += [
-                    [
-                        plotdata.axis,
-                        plotdata.direction,
-                        plotdata.norm_dose,
-                        plotdata.norm_std_dev,
-                    ]
-                    + plotdata.params
-                ]
-            else:
-                self.data += [
-                    [
-                        plotdata.axis,
-                        plotdata.direction,
-                        plotdata.dose,
-                        plotdata.std_dev,
-                    ]
-                    + plotdata.params
+            self.data += [
+                [
+                    plotdata.axis[self.half],
+                    plotdata.direction,
+                    plotdata.dose[self.half][self.norm],
+                    plotdata.std_dev[self.half][self.norm],
                 ]
+                + plotdata.params
+            ]
 
     def add_legend(self):
 
@@ -275,7 +302,7 @@ class DoseFigureHandler:
                 y=plot_data[2],
                 yerr=plot_data[3],
                 fmt="none",
-                ecolor="r",
+                ecolor="black",
                 elinewidth=0.5,
                 capsize=1,
                 capthick=0.2,
@@ -291,17 +318,50 @@ class DoseFigureHandler:
                 label=f"{self.plots[index].filename}",
             )
 
-        if self.zoom == False:
-            try:
-                self.axins.remove()
-            except:
-                pass
+        try:
+            self.axins.remove()
+        except:
+            pass
 
         if self.zoom == True:
+
+            self.canvas.draw()
+            self.transform = self.ax.transData
+            self.inverted_transform = self.ax.transData.inverted()
+            width, height = self.fig.canvas.get_width_height()
+
+            self.focuspoint = self.plots[-1].axis[self.half][
+                len(self.plots[-1].axis[self.half]) // 2
+            ]
             try:
-                self.axins.remove()
-            except:
+                self.focuspoint = self.inverted_transform.transform(
+                    (
+                        width
+                        * (self.parent.canvas.coords(self.parent.oval)[0] + 5)
+                        / self.parent.canvas.image.width(),
+                        1,
+                    )
+                )
+                self.focuspoint = self.plots[-1].axis[self.half][
+                    np.abs(
+                        np.asarray(self.plots[-1].axis[self.half] - self.focuspoint[0])
+                    ).argmin()
+                ]
+            except AttributeError:
                 pass
+            except IndexError:
+                pass
+
+            pixels = self.transform.transform(np.vstack([plot_data[0], plot_data[2]]).T)
+            x, y = pixels.T
+            y = height - y
+
+            self.pixelx = (
+                x[self.plots[-1].axis[self.half].index(self.focuspoint)] / width
+            )
+            self.pixely = (
+                y[self.plots[-1].axis[self.half].index(self.focuspoint)] / height
+            )
 
             self.axins = inset_axes(self.ax, "28%", "28%", loc="lower left")
             yvalsat195 = []
@@ -312,7 +372,7 @@ class DoseFigureHandler:
                     y=plot_data[2],
                     yerr=plot_data[3],
                     fmt="none",
-                    ecolor="r",
+                    ecolor="black",
                     elinewidth=0.5,
                     capsize=1,
                     capthick=0.2,
@@ -330,20 +390,34 @@ class DoseFigureHandler:
                 yvalsat195 += [
                     plot_data[2][
                         plot_data[0].index(
-                            min(plot_data[0], key=lambda x: abs(x - 195))
+                            min(
+                                plot_data[0],
+                                key=lambda x: abs(x - (self.focuspoint - 5)),
+                            )
                         )
                     ]
                 ]
                 yvalsat205 += [
                     plot_data[2][
                         plot_data[0].index(
-                            min(plot_data[0], key=lambda x: abs(x - 205))
+                            min(
+                                plot_data[0],
+                                key=lambda x: abs(x - (self.focuspoint + 5)),
+                            )
                         )
                     ]
                 ]
 
             # sub region of the original image
-            x1, x2, y1, y2 = (195, 205, min(yvalsat205), max(yvalsat195))
+            x1, x2, y1, y2 = (
+                self.focuspoint - 6,
+                self.focuspoint + 6,
+                0.99 * min(yvalsat205),
+                1.01 * max(yvalsat195),
+            )
+            if self.half == True:
+                x1, x2 = x1 + 3, x2 - 3
+
             self.axins.set_xlim(x1, x2)
             self.axins.set_ylim(y1, y2)
             self.axins.tick_params(
@@ -358,6 +432,8 @@ class DoseFigureHandler:
         Passes the image of the plot and the plot type to the MainApplication
         """
 
+        self.half = self.parent.half.get()
+
         self.set_axis()
         self.add_plot_data(filenames)
         self.set_style()
