@@ -19,6 +19,8 @@ class MainApplication(tk.Frame):
 
         self.parent = parent
 
+        self.parent.protocol("WM_DELETE_WINDOW", lambda: self.save_graph(True))
+
         # Read settings from profile.json and initialize the necessary variables
         self.profile = ProfileHandler()
         self.lang = self.profile.get_attribute("language")
@@ -36,9 +38,13 @@ class MainApplication(tk.Frame):
         self.zoom = tk.BooleanVar()
         self.zoom.set(bool(self.profile.get_attribute("zoom")))
 
-        self.DoseFigureHandler = DoseFigureHandler(
-            self, self.norm.get(), self.zoom.get()
-        )
+        self.half = tk.BooleanVar()
+        self.half.set(bool(self.profile.get_attribute("halfview")))
+
+        self.fullscreen = tk.BooleanVar()
+        self.fullscreen.set(bool(self.profile.get_attribute("fullscreen")))
+
+        self.DoseFigureHandler = DoseFigureHandler(self)
 
         self.parent.title(self.text.window_title[self.lang])
         style = ttk.Style(self.parent)
@@ -65,6 +71,7 @@ class MainApplication(tk.Frame):
         self.parent.bind("<Control-p>", self.p_key)
         self.parent.bind("<Escape>", self.esc_key)
         self.parent.bind("<Control-z>", self.z_key)
+        self.parent.bind("<F11>", self.toggle_fullscreen)
 
         # Menubar definitions
         self.menubar = tk.Menu(self.parent)
@@ -107,7 +114,7 @@ class MainApplication(tk.Frame):
         )
         self.filemenu.add_separator()
         self.filemenu.add_command(
-            label=self.text.end[self.lang], command=self.parent.destroy
+            label=self.text.end[self.lang], command=lambda: self.save_graph(True)
         )
         self.filemenu.entryconfig(3, state=tk.DISABLED)
         self.filemenu.entryconfig(4, state=tk.DISABLED)
@@ -143,6 +150,16 @@ class MainApplication(tk.Frame):
             onvalue=1,
             offvalue=0,
         )
+
+        self.viewmenu.add_checkbutton(
+            label=self.text.fullscreen[self.lang],
+            variable=self.fullscreen,
+            command=self.toggle_fullscreen,
+            onvalue=1,
+            offvalue=0,
+            accelerator="F11",
+        )
+
         self.menubar.add_cascade(label=self.text.view[self.lang], menu=self.viewmenu)
         self.optionsmenu = tk.Menu(self.menubar)
         self.optionsmenu.add_checkbutton(
@@ -175,15 +192,7 @@ class MainApplication(tk.Frame):
         )
 
         self.normmenu = tk.Menu(self.menubar)
-        self.normmenu.add_checkbutton(
-            label=self.text.normalize[self.lang],
-            command=self.normalize,
-            variable=self.norm,
-        )
-        self.normmenu.add_checkbutton(
-            label=self.text.zoom[self.lang], command=self.zoomgraph, variable=self.zoom,
-        )
-        self.normmenu.add_separator()
+
         self.markersizemenu = tk.Menu(self.menubar)
         self.markersizemenu.add_command(
             label=Text().increase[self.lang],
@@ -219,11 +228,27 @@ class MainApplication(tk.Frame):
             label=Text().marker[self.lang], menu=self.markersizemenu
         )
 
+        self.normmenu.add_separator()
+        self.normmenu.add_checkbutton(
+            label=self.text.normalize[self.lang],
+            command=self.normalize,
+            variable=self.norm,
+        )
+
+        self.normmenu.add_checkbutton(
+            label=self.text.zoom[self.lang], command=self.zoomgraph, variable=self.zoom,
+        )
+        self.normmenu.add_checkbutton(
+            label=self.text.half[self.lang], command=self.halfgraph, variable=self.half,
+        )
+
         self.parent.config(menu=self.menubar)
 
         # Initialize necessary variables
+        self.saved = True
         self.menuflag = False
         self.canvas = tk.Canvas(self)
+        self._drag_data = {"x": 0, "y": 0, "item": None}
         self.photoimage = None
         self.image_on_canvas = None
         self.canvas.image = None
@@ -232,8 +257,14 @@ class MainApplication(tk.Frame):
         self.rename_boxes = []
 
         self.parent.geometry(geometry)
+        self.parent.attributes("-fullscreen", self.fullscreen.get())
         self.pack(side="top", fill="both", expand=True)
 
+    def toggle_fullscreen(self, event=None):
+        self.parent.attributes("-fullscreen", not self.parent.attributes("-fullscreen"))
+        self.fullscreen.set(self.parent.attributes("-fullscreen"))
+        self.profile.set_attribute("fullscreen", bool(self.fullscreen.get()))
+
     def autostart(self):
 
         """
@@ -315,6 +346,12 @@ class MainApplication(tk.Frame):
             self.show_preview()
         return
 
+    def halfgraph(self):
+        self.DoseFigureHandler.half = self.half.get()
+        self.profile.set_attribute("halfview", self.half.get())
+        self.show_preview()
+        return
+
     def change_marker_size(self, boolean):
         if boolean == True:
             self.DoseFigureHandler.markersize += 0.2
@@ -376,6 +413,7 @@ class MainApplication(tk.Frame):
         self.filemenu.entryconfig(1, state=tk.DISABLED)
         self.filemenu.entryconfig(3, state=tk.NORMAL)
         self.filemenu.entryconfig(4, state=tk.NORMAL)
+        self.saved = False
 
     def close_file(self):
 
@@ -398,6 +436,7 @@ class MainApplication(tk.Frame):
         self.menuflag = False
         self.DoseFigureHandler.flush()
         self.DoseFigureHandler.plots = []
+        self.saved = True
 
     def remove_last_addition(self):
 
@@ -426,12 +465,25 @@ class MainApplication(tk.Frame):
         self.canvas.itemconfig(self.image_on_canvas, image=None)
         self.show_preview()
 
-    def save_graph(self):
+    def save_graph(self, exit=False):
 
         """
         Saves the current graph
         """
 
+        if exit == True:
+            if self.saved == False:
+
+                prompt = sd.messagebox.askyesno("", self.text.closeprompt[self.lang])
+                if prompt == True:
+                    self.parent.destroy()
+                    return
+                else:
+                    return
+            else:
+                self.parent.destroy()
+                return
+
         file = fd.asksaveasfilename(
             defaultextension=".png",
             filetypes=[(self.text.image[self.lang], [".png", ".jpg"])],
@@ -441,6 +493,7 @@ class MainApplication(tk.Frame):
             return
 
         ImageTk.getimage(self.photoimage).save(file)
+        self.saved = True
         return
 
     def show_preview(self):
@@ -456,6 +509,7 @@ class MainApplication(tk.Frame):
         self.canvas.bind("<Configure>", self.handle_configure)
         self.canvas.bind("<Button-1>", self.check_click)
         self.canvas.bind("<Motion>", self.check_hand)
+        self.canvas.bind("<Double-Button-1>", self.new_zoom)
         self.canvas.pack(side=tk.TOP, fill="both", expand=True)
 
         if len(self.DoseFigureHandler.plots) >= 2:
@@ -467,8 +521,10 @@ class MainApplication(tk.Frame):
 
         if menuflag == "Z":
             self.addmeasuremenu.entryconfig(1, state=tk.DISABLED)
+            self.normmenu.entryconfig(5, state=tk.DISABLED)
         else:
             self.addmeasuremenu.entryconfig(0, state=tk.DISABLED)
+            self.normmenu.entryconfig(5, state=tk.NORMAL)
 
         if self.menuflag == False:
             self.menubar.add_cascade(label=self.text.add[self.lang], menu=self.addmenu)
@@ -502,7 +558,29 @@ class MainApplication(tk.Frame):
             )
             self.rename_boxes += [temp]
 
-    # Keybind functions
+        if self.zoom.get() == True:
+
+            self.pixelx = self.DoseFigureHandler.pixelx
+            self.pixely = self.DoseFigureHandler.pixely
+
+            self.oval = self.canvas.create_oval(
+                self.pixelx * self.canvas.image.width() - 5,
+                self.pixely * self.canvas.image.height() - 5,
+                self.pixelx * self.canvas.image.width() + 5,
+                self.pixely * self.canvas.image.height() + 5,
+                fill="",
+                outline="",
+                tags="token",
+            )
+
+    def new_zoom(self, event):
+
+        if self.zoom.get() == True:
+
+            delta_x = event.x - self.canvas.coords(self.oval)[0] + 5
+            delta_y = event.y - self.canvas.coords(self.oval)[1] + 5
+            self.canvas.move(self.oval, delta_x, delta_y)
+            self.show_preview()
 
     def handle_configure(self, event):
 
@@ -561,9 +639,23 @@ class MainApplication(tk.Frame):
                     (0.065 + 0.042 * i) * y,
                     fill="",
                     outline="",
+                    tags="rename",
                 )
             ]
 
+        self.canvas.delete("token")
+
+        if self.zoom.get() == True:
+            self.oval = self.canvas.create_oval(
+                self.pixelx * self.canvas.image.width() - 5,
+                self.pixely * self.canvas.image.height() - 5,
+                self.pixelx * self.canvas.image.width() + 5,
+                self.pixely * self.canvas.image.height() + 5,
+                fill="",
+                outline="",
+                tags="token",
+            )
+
     def check_hand(self, e):
         if e != None:
             try:
