@@ -13,14 +13,20 @@ class Text:
             "de": "Derzeitige Ansicht schließen",
             "en": "Close current project",
         }
+        self.closeprompt = {
+            "de": "Graph wurde noch nicht gespeichert. Trotzdem Schließen?",
+            "en": "Graph was not saved. Close anyways?",
+        }
         self.dark = {"de": "Dunkel", "en": "Dark"}
         self.decrease = {"de": "Verkleinern", "en": "Decrease"}
         self.dp = {"de": "Dosisquerverteilung", "en": "Dose profile"}
         self.end = {"de": "Beenden", "en": "Close"}
         self.english = {"de": "Englisch", "en": "English"}
         self.file = {"de": "Datei", "en": "File"}
+        self.fullscreen = {"de": "Vollbild", "en": "Fullscreen"}
         self.fwhm = {"de": "HWB", "en": "FWHM"}
         self.german = {"de": "Deutsch", "en": "German"}
+        self.half = {"de": "Halbe Querverteilung anzeigen", "en": "Show half profile"}
         self.histnum = {
             "de": "Anzahl der Historien in der Simulation:",
             "en": "Histories in Simulation:",
@@ -28,6 +34,16 @@ class Text:
         self.histories = {"de": "Historien", "en": "Histories"}
         self.image = {"de": "Bilder", "en": "Images"}
         self.increase = {"de": "Vergrößern", "en": "Increase"}
+        self.incordata = {
+            "de": {
+                1: " wurde nicht importiert - unpassender Messtyp!",
+                2: " wurden nicht importiert - unpassende Messtypen!",
+            },
+            "en": {
+                1: " was not imported - incompatible measurement!",
+                2: " were not imported - incompatible measurements!",
+            },
+        }
         self.language = {"de": "Sprache", "en": "Language"}
         self.languageset = {
             "en": "Das geöffnete Projekt wird geschlossen. Fortfahren?",
